==> hal-console-3.0.21.Final-redhat-00001-sources.jar: org/jboss/hal/client/homepage/HomepageHelp.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.client.homepage;

import javax.annotation.PostConstruct;

import elemental2.dom.HTMLElement;
import org.jboss.gwt.elemento.core.IsElement;
import org.jboss.gwt.elemento.template.DataElement;
import org.jboss.gwt.elemento.template.Templated;
import org.jboss.hal.config.Build;
import org.jboss.hal.config.Environment;
import org.jboss.hal.resources.Resources;

import static org.jboss.gwt.elemento.core.Elements.a;
import static org.jboss.gwt.elemento.core.Elements.li;
import static org.jboss.hal.resources.Urls.*;

@Templated("Homepage.html#homepage-help")
abstract class HomepageHelp implements IsElement {

    // @formatter:off
    static HomepageHelp create(final Environment environment, final Resources resources) {
        return new Templated_HomepageHelp(environment, resources);
    }

    abstract Environment environment();
    abstract Resources resources();
    // @formatter:on


    @DataElement HTMLElement generalResources;
    @DataElement HTMLElement getHelp;

    @PostConstruct
    void init() {
        if (environment().getHalBuild() == Build.COMMUNITY) {
            generalResources.appendChild(helpLink(WILDFLY_HOMEPAGE,
                    resources().constants().homepageHelpWildFlyHomeText()));
            generalResources.appendChild(helpLink(WILDFLY_10_DOCUMENTATION,
                    resources().constants().homepageHelpWilfdflyDocumentationText()));
            generalResources.appendChild(helpLink(WILDFLY_10_ADMIN_GUIDE,
                    resources().constants().homepageHelpAdminGuideText()));
            generalResources.appendChild(helpLink(WILDSCRIBE_GITHUB_IO,
                    resources().constants().homepageHelpModelReferenceText()));
            generalResources.appendChild(helpLink(WILDFLY_ISSUES,
                    resources().constants().homepageHelpWildflyIssuesText()));
            generalResources.appendChild(helpLink(WILDFLY_NEWS, resources().constants().homepageHelpLatestNews()));

            getHelp.appendChild(helpLink(JBOSS_ORG_DEVELOPER_MATERIALS,
                    resources().constants().homepageHelpTutorialsText()));
            getHelp.appendChild(helpLink(JBOSS_COMMUNITY_DISCUSSIONS,
                    resources().constants().homepageHelpUserForumsText()));
            getHelp.appendChild(helpLink(WILDFLY_IRC, resources().constants().homepageHelpIrcText()));
            getHelp.appendChild(helpLink(WILDFLY_DEV_MAILING_LIST,
                    resources().constants().homepageHelpDevelopersMailingListText()));
        } else {
            generalResources.appendChild(helpLink(resources().constants().homepageHelpEapDocumentationLink(),
                    resources().constants().homepageHelpEapDocumentationText()));
            generalResources.appendChild(helpLink(resources().constants().homepageHelpLearnMoreEapLink(),
                    resources().constants().homepageHelpLearnMoreEapText()));
            generalResources.appendChild(helpLink(resources().constants().homepageHelpTroubleTicketLink(),
                    resources().constants().homepageHelpTroubleTicketText()));
            generalResources.appendChild(helpLink(resources().constants().homepageHelpTrainingLink(),
                    resources().constants().homepageHelpTrainingText()));

            getHelp.appendChild(helpLink(resources().constants().homepageHelpTutorialsLink(),
                    resources().constants().homepageHelpTutorialsText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpEapCommunityLink(),
                    resources().constants().homepageHelpEapCommunityText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpEapConfigurationsLink(),
                    resources().constants().homepageHelpEapConfigurationsText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpKnowledgebaseLink(),
                    resources().constants().homepageHelpKnowledgebaseText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpConsultingLink(),
                    resources().constants().homepageHelpConsultingText()));
        }
    }

    private HTMLElement helpLink(final String href, final String text) {
        return li().add(a(href).textContent(text)).asElement();
    }
}

==> hal-console-3.2.4.Final-redhat-00001-sources.jar: org/jboss/hal/client/homepage/HomepageHelp.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.client.homepage;

import javax.annotation.PostConstruct;

import elemental2.dom.HTMLElement;
import org.jboss.gwt.elemento.core.IsElement;
import org.jboss.gwt.elemento.template.DataElement;
import org.jboss.gwt.elemento.template.Templated;
import org.jboss.hal.config.Build;
import org.jboss.hal.config.Environment;
import org.jboss.hal.resources.Resources;

import static org.jboss.gwt.elemento.core.Elements.a;
import static org.jboss.gwt.elemento.core.Elements.li;
import static org.jboss.hal.resources.Urls.*;

@Templated("Homepage.html#homepage-help")
abstract class HomepageHelp implements IsElement {

    // @formatter:off
    static HomepageHelp create(Environment environment, Resources resources) {
        return new Templated_HomepageHelp(environment, resources);
    }

    abstract Environment environment();
    abstract Resources resources();
    // @formatter:on


    @DataElement HTMLElement generalResources;
    @DataElement HTMLElement getHelp;

    @PostConstruct
    void init() {
        if (environment().getHalBuild() == Build.COMMUNITY) {
            generalResources.appendChild(helpLink(WILDFLY_HOMEPAGE,
                    resources().constants().homepageHelpWildFlyHomeText()));
            generalResources.appendChild(helpLink(WILDFLY_DOCUMENTATION,
                    resources().constants().homepageHelpWilfdflyDocumentationText()));
            generalResources.appendChild(helpLink(WILDSCRIBE_GITHUB_IO,
                    resources().constants().homepageHelpModelReferenceText()));
            generalResources.appendChild(helpLink(WILDFLY_ISSUES,
                    resources().constants().homepageHelpWildflyIssuesText()));
            generalResources.appendChild(helpLink(WILDFLY_NEWS, resources().constants().homepageHelpLatestNews()));

            getHelp.appendChild(helpLink(JBOSS_ORG_DEVELOPER_MATERIALS,
                    resources().constants().homepageHelpTutorialsText()));
            getHelp.appendChild(helpLink(JBOSS_COMMUNITY_DISCUSSIONS,
                    resources().constants().homepageHelpUserForumsText()));
            getHelp.appendChild(helpLink(WILDFLY_IRC, resources().constants().homepageHelpIrcText()));
            getHelp.appendChild(helpLink(WILDFLY_DEV_MAILING_LIST,
                    resources().constants().homepageHelpDevelopersMailingListText()));
        } else {
            generalResources.appendChild(helpLink(resources().constants().homepageHelpEapDocumentationLink(),
                    resources().constants().homepageHelpEapDocumentationText()));
            generalResources.appendChild(helpLink(resources().constants().homepageHelpLearnMoreEapLink(),
                    resources().constants().homepageHelpLearnMoreEapText()));
            generalResources.appendChild(helpLink(resources().constants().homepageHelpTroubleTicketLink(),
                    resources().constants().homepageHelpTroubleTicketText()));
            generalResources.appendChild(helpLink(resources().constants().homepageHelpTrainingLink(),
                    resources().constants().homepageHelpTrainingText()));

            getHelp.appendChild(helpLink(resources().constants().homepageHelpTutorialsLink(),
                    resources().constants().homepageHelpTutorialsText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpEapCommunityLink(),
                    resources().constants().homepageHelpEapCommunityText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpEapConfigurationsLink(),
                    resources().constants().homepageHelpEapConfigurationsText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpKnowledgebaseLink(),
                    resources().constants().homepageHelpKnowledgebaseText()));
            getHelp.appendChild(helpLink(resources().constants().homepageHelpConsultingLink(),
                    resources().constants().homepageHelpConsultingText()));
        }
    }

    private HTMLElement helpLink(String href, String text) {
        return li().add(a(href).textContent(text)).get();
    }
}
